function xReturn = getAphiaID(obj,scientificname,marine_only)
%getAphiaID(obj,scientificname,marine_only)
%
%   <strong>Get the AphiaID for a given name.
%   
%   Output: NULL when no match is found; -999 when multiple matches are found; an integer (AphiaID) when one exact match was found</strong>
%   		<br />Parameters:
%   		<ul>
%   			<li><u>marine_only</u>: Limit to marine taxa. Default=true</li>
%   		</ul>
%   		<br />Returns:
%   		<ul>
%   			<li> NULL when no match is found</li>
%   			<li> -999 when multiple matches are found</li>
%   			<li> an integer (AphiaID) when one exact match was found</li>
%   		</ul>
%   
%     Input:
%       scientificname = (string)
%       marine_only = (boolean)
%   
%     Output:
%       return = (int)

% Build up the argument lists.
values = { ...
   scientificname, ...
   marine_only, ...
   };
names = { ...
   'scientificname', ...
   'marine_only', ...
   };
types = { ...
   '{http://www.w3.org/2001/XMLSchema}string', ...
   '{http://www.w3.org/2001/XMLSchema}boolean', ...
   };

% Create the message, make the call, and convert the response into a variable.
soapMessage = createSoapMessage( ...
    'http://aphia/v1.0/AphiaID', ...
    'getAphiaID', ...
    values,names,types,'rpc');
response = callSoapService( ...
    obj.endpoint, ...
    'getAphiaID', ...
    soapMessage);
xReturn = parseSoapResponse(response);
