function xReturn = getSourcesByAphiaID(obj,AphiaID)
%getSourcesByAphiaID(obj,AphiaID)
%
%   <strong>Get one or more sources/references including links, for one AphiaID</strong>
%   	<br />Output fields include:
%   	<br /> <ul><li>	<u><b>source_id</b></u> : Unique identifier for the source within WoRMS</li><li>	<u><b>use</b></u> : Usage of the source for this taxon. See <a href='https://www.marinespecies.org/aphia.php?p=manual#topic6' target='_blank'>here</a> for all values</li><li>	<u><b>reference</b></u> : Full citation string</li><li>	<u><b>page</b></u> : Page(s) where the taxon is mentioned</li><li>	<u><b>url</b></u> : Direct link to the source record</li><li>	<u><b>link</b></u> : External link (i.e. journal, data system, etc..)</li><li>	<u><b>fulltext</b></u> : Full text link (PDF)</li><li>	<u><b>doi</b></u> : Digital Object Identifier</li></ul>
%   
%     Input:
%       AphiaID = (int)
%   
%     Output:
%       return{:} = (Source)

% Build up the argument lists.
values = { ...
   AphiaID, ...
   };
names = { ...
   'AphiaID', ...
   };
types = { ...
   '{http://www.w3.org/2001/XMLSchema}int', ...
   };

% Create the message, make the call, and convert the response into a variable.
soapMessage = createSoapMessage( ...
    'http://aphia/v1.0/Sources', ...
    'getSourcesByAphiaID', ...
    values,names,types,'rpc');
response = callSoapService( ...
    obj.endpoint, ...
    'getSourcesByAphiaID', ...
    soapMessage);
xReturn = parseSoapResponse(response);
